@@ -142,14 +142,14 @@ impl<'dir> File<'dir> {
             RecursiveSize::None
         };
 
-        debug!("deref_links {}", deref_links);
+        debug!("deref_links {deref_links}");
 
         let filetype = match filetype {
             Some(f) => OnceLock::from(Some(f)),
             None => OnceLock::new(),
         };
 
-        debug!("deref_links {}", deref_links);
+        debug!("deref_links {deref_links}");
 
         let mut file = File {
             name,
@@ -228,7 +228,7 @@ impl<'dir> File<'dir> {
             back.as_os_str().to_string_lossy().to_string()
         } else {
             // use the path as fallback
-            error!("Path {:?} has no last component", path);
+            error!("Path {path:?} has no last component");
             path.display().to_string()
         }
     }
@@ -294,7 +294,7 @@ impl<'dir> File<'dir> {
 
     /// Whether this file is a directory on the filesystem.
     pub fn is_directory(&self) -> bool {
-        self.filetype().map_or(false, std::fs::FileType::is_dir)
+        self.filetype().is_some_and(std::fs::FileType::is_dir)
     }
 
     /// Whether this file is a directory, or a symlink pointing to a directory.
@@ -313,21 +313,29 @@ impl<'dir> File<'dir> {
         false
     }
 
+    /// Initializes a new `Dir` object using the `PathBuf` of
+    /// the current file. It does not perform any validation to check if the
+    /// file is actually a directory. To verify that, use `is_directory()`.
+    pub fn to_dir(&self) -> Dir {
+        trace!("read_dir: initializating dir from path");
+        Dir::new(self.path.clone())
+    }
+
     /// If this file is a directory on the filesystem, then clone its
     /// `PathBuf` for use in one of our own `Dir` values, and read a list of
     /// its contents.
     ///
     /// Returns an IO error upon failure, but this shouldn’t be used to check
     /// if a `File` is a directory or not! For that, just use `is_directory()`.
-    pub fn to_dir(&self) -> io::Result<Dir> {
-        trace!("to_dir: reading dir");
+    pub fn read_dir(&self) -> io::Result<Dir> {
+        trace!("read_dir: reading dir");
         Dir::read_dir(self.path.clone())
     }
 
     /// Whether this file is a regular file on the filesystem — that is, not a
     /// directory, a link, or anything else treated specially.
     pub fn is_file(&self) -> bool {
-        self.filetype().map_or(false, std::fs::FileType::is_file)
+        self.filetype().is_some_and(std::fs::FileType::is_file)
     }
 
     /// Whether this file is both a regular file *and* executable for the
@@ -347,31 +355,31 @@ impl<'dir> File<'dir> {
 
     /// Whether this file is a symlink on the filesystem.
     pub fn is_link(&self) -> bool {
-        self.filetype().map_or(false, FileType::is_symlink)
+        self.filetype().is_some_and(FileType::is_symlink)
     }
 
     /// Whether this file is a named pipe on the filesystem.
     #[cfg(unix)]
     pub fn is_pipe(&self) -> bool {
-        self.filetype().map_or(false, FileTypeExt::is_fifo)
+        self.filetype().is_some_and(FileTypeExt::is_fifo)
     }
 
     /// Whether this file is a char device on the filesystem.
     #[cfg(unix)]
     pub fn is_char_device(&self) -> bool {
-        self.filetype().map_or(false, FileTypeExt::is_char_device)
+        self.filetype().is_some_and(FileTypeExt::is_char_device)
     }
 
     /// Whether this file is a block device on the filesystem.
     #[cfg(unix)]
     pub fn is_block_device(&self) -> bool {
-        self.filetype().map_or(false, FileTypeExt::is_block_device)
+        self.filetype().is_some_and(FileTypeExt::is_block_device)
     }
 
     /// Whether this file is a socket on the filesystem.
     #[cfg(unix)]
     pub fn is_socket(&self) -> bool {
-        self.filetype().map_or(false, FileTypeExt::is_socket)
+        self.filetype().is_some_and(FileTypeExt::is_socket)
     }
 
     /// Determine the full path resolving all symbolic links on demand.
@@ -598,20 +606,21 @@ impl<'dir> File<'dir> {
             // functions major and minor.  On Linux the try_into().unwrap() and
             // the "as u32" cast are not needed.  We turn off the warning to
             // allow it to compile cleanly on Linux.
-            #[allow(trivial_numeric_casts)]
+            //
+            // On illumos and Solaris, major and minor are extern "C" fns and
+            // therefore unsafe; on other platforms the functions are defined as
+            // macros and copied as const fns in the libc crate.
+            #[allow(trivial_numeric_casts, unused_unsafe)]
             #[allow(clippy::unnecessary_cast, clippy::useless_conversion)]
-            f::Size::DeviceIDs(f::DeviceIDs {
-                major: libc::major(
-                    device_id
-                        .try_into()
-                        .expect("Malformed device major ID when getting filesize"),
-                ) as u32,
-                minor: libc::minor(
-                    device_id
-                        .try_into()
-                        .expect("Malformed device major ID when getting filesize"),
-                ) as u32,
-            })
+            {
+                let device_id = device_id
+                    .try_into()
+                    .expect("Malformed device major ID when getting filesize");
+                f::Size::DeviceIDs(f::DeviceIDs {
+                    major: unsafe { libc::major(device_id) as u32 },
+                    minor: unsafe { libc::minor(device_id) as u32 },
+                })
+            }
         } else if self.is_file() {
             f::Size::Some(self.metadata().map_or(0, std::fs::Metadata::len))
         } else {
@@ -1016,7 +1025,7 @@ pub enum FileTarget<'dir> {
     // error — we just display the error message and move on.
 }
 
-impl<'dir> FileTarget<'dir> {
+impl FileTarget<'_> {
     /// Whether this link doesn’t lead to a file, for whatever reason. This
     /// gets used to determine how to highlight the link in grid views.
     #[must_use]
