@@ -5,24 +5,31 @@
 // SPDX-FileCopyrightText: 2014 Benjamin Sago
 // SPDX-License-Identifier: MIT
 use crate::theme::ThemeFileType as FileType;
-use crate::theme::*;
+use crate::theme::{
+    FileKinds, FileNameStyle, Git, GitRepo, IconStyle, Links, Permissions, SELinuxContext,
+    SecurityContext, Size, UiStyles, Users,
+};
 use nu_ansi_term::{Color, Style};
 use serde::{Deserialize, Deserializer, Serialize};
 use serde_norway;
 use std::collections::HashMap;
 use std::path::PathBuf;
 
-#[derive(Debug, Default, Eq, PartialEq)]
+#[derive(Debug, Eq, PartialEq)]
 pub struct ThemeConfig {
     // This is rather bare for now, will be expanded with config file
-    location: ConfigLoc,
+    location: PathBuf,
 }
 
-#[derive(Debug, Default, PartialEq, Eq)]
-pub enum ConfigLoc {
-    #[default]
-    Default, // $XDG_CONFIG_HOME/eza/config|theme.yml
-    Env(PathBuf), // $EZA_CONFIG_DIR
+impl Default for ThemeConfig {
+    fn default() -> Self {
+        ThemeConfig {
+            location: dirs::config_dir()
+                .unwrap_or_default()
+                .join("eza")
+                .join("theme.yml"),
+        }
+    }
 }
 
 trait FromOverride<T>: Sized {
@@ -45,7 +52,7 @@ where
 
 #[rustfmt::skip]
 fn color_from_str(s: &str) -> Option<Color> {
-    use Color::*;
+    use Color::{Black, Blue, Cyan, DarkGray, Default, Fixed, Green, LightBlue, LightCyan, LightGray, LightGreen, LightMagenta, LightPurple, LightRed, LightYellow, Magenta, Purple, Red, Rgb, White, Yellow};
     match s {
         // nothing
         "" | "none"    | "None"         => None,
@@ -600,23 +607,15 @@ impl FromOverride<UiStylesOverride> for UiStyles {
     }
 }
 impl ThemeConfig {
-    pub fn from_path(path: &str) -> Self {
-        let path = PathBuf::from(path);
-        ThemeConfig {
-            location: ConfigLoc::Env(path),
-        }
+    #[must_use]
+    pub fn from_path(path: PathBuf) -> Self {
+        ThemeConfig { location: path }
     }
+    #[must_use]
     pub fn to_theme(&self) -> Option<UiStyles> {
-        let ui_styles_override: Option<UiStylesOverride> = match &self.location {
-            ConfigLoc::Default => {
-                let path = dirs::config_dir()?.join("eza").join("theme.yml");
-                let file = std::fs::File::open(path).ok()?;
-                serde_norway::from_reader(&file).ok()
-            }
-            ConfigLoc::Env(path) => {
-                let file = std::fs::File::open(path).ok()?;
-                serde_norway::from_reader(&file).ok()
-            }
+        let ui_styles_override: Option<UiStylesOverride> = {
+            let file = std::fs::File::open(&self.location).ok()?;
+            serde_norway::from_reader(&file).ok()
         };
         FromOverride::from(ui_styles_override, Some(UiStyles::default()))
     }
@@ -656,7 +655,7 @@ mod tests {
 
     #[test]
     fn parse_short_hex_color_from_string() {
-        for case in ["#f0f", "#F0F"].iter() {
+        for case in &["#f0f", "#F0F"] {
             assert_eq!(color_from_str(case), Some(Color::Rgb(255, 0, 255)));
         }
     }
