@@ -1,3 +1,9 @@
+// SPDX-FileCopyrightText: 2024 Christina Sørensen
+// SPDX-License-Identifier: EUPL-1.2
+//
+// SPDX-FileCopyrightText: 2023-2024 Christina Sørensen, eza contributors
+// SPDX-FileCopyrightText: 2014 Benjamin Sago
+// SPDX-License-Identifier: MIT
 #[cfg(unix)]
 mod blocks;
 #[cfg(unix)]
@@ -40,8 +46,31 @@ pub use self::users::Colours as UserColours;
 pub use self::users::Render as UserRender;
 
 mod octal;
+#[cfg(unix)]
 pub use self::octal::Render as OctalPermissionsRender;
 // octal uses just one colour
 
 mod securityctx;
 pub use self::securityctx::Colours as SecurityCtxColours;
+
+#[cfg(any(
+    target_os = "macos",
+    target_os = "freebsd",
+    target_os = "netbsd",
+    target_os = "openbsd",
+    target_os = "dragonfly"
+))]
+mod flags_bsd;
+
+#[cfg(windows)]
+mod flags_windows;
+
+#[cfg(not(any(
+    target_os = "macos",
+    target_os = "freebsd",
+    target_os = "netbsd",
+    target_os = "openbsd",
+    target_os = "dragonfly",
+    target_os = "windows"
+)))]
+mod flags;
